package de.intevation.flys.artifacts.context;

import org.apache.log4j.Logger;

import org.hibernate.Session;

import de.intevation.artifacts.CallContext;
import de.intevation.artifacts.CallContext.Listener;

import de.intevation.flys.artifacts.model.SessionHolder;


/**
 * This CallContextListener is used to initialize a ThreadLocal variable in
 * each CallContext (for each request) that holds Sessions.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class SessionCallContextListener implements Listener {

    public static final String SESSION_KEY = "context.session";

    /** The logger that is used in this class.*/
    private static Logger logger =
        Logger.getLogger(SessionCallContextListener.class);


    public SessionCallContextListener() {
    }


    /**
     * Initializes a ThreadLocal variable that is used to hold sessions.
     *
     * @param context The CallContext.
     */
    public void init(CallContext context) {
        logger.debug("SessionCallContextListener.init");

        Session session = SessionHolder.acquire();

        context.putContextValue(SESSION_KEY, session);
    }


    /**
     * Closes open sessions of the ThreadLocal variable opened in init().
     *
     * @param context The CallContext.
     */
    public void close(CallContext context) {
        logger.debug("SessionCallContextListener.close");

        Session session = (Session)context.getContextValue(SESSION_KEY);
        session.close();

        SessionHolder.release();
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
