package de.intevation.flys.artifacts.model;

import org.apache.log4j.Logger;

import org.hibernate.Session;
import org.hibernate.SessionFactory;

import de.intevation.flys.backend.SessionFactoryProvider;

public class SessionHolder
{
    private static Logger logger =
        Logger.getLogger(SessionHolder.class);
    
    public static final ThreadLocal<Session> HOLDER =
        new ThreadLocal<Session>() {
            protected Session initialValue() {
                return create();
            }
        };

    private SessionHolder() {
    }

    public synchronized static Session create() {
        logger.debug("create");
        SessionFactory sessionFactory =
            SessionFactoryProvider.createSessionFactory();
        return sessionFactory.openSession();
    }

    public static Session acquire() {
        logger.debug("acquire");
        Session session = create();
        HOLDER.set(session);
        return session;
    }

    public static void release() {
        logger.debug("release");
        HOLDER.remove();
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
